Enum serde_bencode::error::Error
[−]
[src]
pub enum Error {
IoError(IoError),
InvalidType(String),
InvalidValue(String),
InvalidLength(String),
UnknownVariant(String),
UnknownField(String),
MissingField(String),
DuplicateField(String),
Custom(String),
EndOfStream,
}Variants
IoError(IoError)InvalidType(String)InvalidValue(String)InvalidLength(String)UnknownVariant(String)UnknownField(String)MissingField(String)DuplicateField(String)Custom(String)EndOfStreamTrait Implementations
impl Debug for Error[src]
impl SerError for Error[src]
fn custom<T: Display>(msg: T) -> Self
Used when a [Serialize] implementation encounters any error while serializing a type. Read more
impl DeError for Error[src]
fn custom<T: Display>(msg: T) -> Self
Raised when there is general error when deserializing a type. Read more
fn invalid_type(unexp: Unexpected, exp: &Expected) -> Self
Raised when a Deserialize receives a type different from what it was expecting. Read more
fn invalid_value(unexp: Unexpected, exp: &Expected) -> Self
Raised when a Deserialize receives a value of the right type but that is wrong for some other reason. Read more
fn invalid_length(len: usize, exp: &Expected) -> Self
Raised when deserializing a sequence or map and the input data contains too many or too few elements. Read more
fn unknown_variant(field: &str, expected: &'static [&'static str]) -> Self
Raised when a Deserialize enum type received a variant with an unrecognized name. Read more
fn unknown_field(field: &str, expected: &'static [&'static str]) -> Self
Raised when a Deserialize struct type received a field with an unrecognized name. Read more
fn missing_field(field: &'static str) -> Self
Raised when a Deserialize struct type expected to receive a required field with a particular name but that field was not present in the input. Read more
fn duplicate_field(field: &'static str) -> Self
Raised when a Deserialize struct type received more than one of the same field. Read more
impl StdError for Error[src]
fn description(&self) -> &str
A short description of the error. Read more
fn cause(&self) -> Option<&StdError>
The lower-level cause of this error, if any. Read more